@@ -286,6 +286,11 @@
         <source>Hibernate Key Action:</source>
         <translation>Handling for dvaletast:</translation>
     </message>
+    <message>
+        <location filename="../powerkeyssettings.cpp" line="48"/>
+        <source>Note: Under Wayland, power keys are configured by the compositor instead.</source>
+        <translation>Bemærk: Under Wayland indstilles tænd/sluk-taster i kompositoren i stedet.</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
