@@ -286,6 +286,11 @@
         <source>Hibernate Key Action:</source>
         <translation>Ruhezustand-Tastenaktion:</translation>
     </message>
+    <message>
+        <location filename="../powerkeyssettings.cpp" line="48"/>
+        <source>Note: Under Wayland, power keys are configured by the compositor instead.</source>
+        <translation>Hinweis: Unter Wayland werden die Ein-/Aus-Tasten stattdessen vom Kompositor konfiguriert.</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
