@@ -286,6 +286,11 @@
         <source>Hibernate Key Action:</source>
         <translation>Acción de tecla de hibernación:</translation>
     </message>
+    <message>
+        <location filename="../powerkeyssettings.cpp" line="48"/>
+        <source>Note: Under Wayland, power keys are configured by the compositor instead.</source>
+        <translation>Nota: Bajo Wayland, las teclas de apagado son configuradas por el compositor.</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
