@@ -62,13 +62,13 @@
     <message>
         <location filename="../batterywatchersettings.ui" line="97"/>
         <source>Show icon:</source>
-        <translation>Vis symbol:</translation>
+        <translation>Vis ikon:</translation>
     </message>
     <message>
         <location filename="../batterywatchersettings.cpp" line="41"/>
         <source>from theme</source>
         <comment>icons</comment>
-        <translation>fra drakt</translation>
+        <translation>fra tema</translation>
     </message>
     <message>
         <location filename="../batterywatchersettings.cpp" line="42"/>
@@ -125,17 +125,17 @@
     <message>
         <location filename="../idlenesswatchersettings.ui" line="83"/>
         <source>When idle on Battery:</source>
-        <translation>Ved lediggang på batteri:</translation>
+        <translation>Ved inaktivitet på batteri:</translation>
     </message>
     <message>
         <location filename="../idlenesswatchersettings.ui" line="90"/>
         <source>Battery Idle time:</source>
-        <translation>Lediggangstid på batteri:</translation>
+        <translation>Inaktivitetstid på batteri:</translation>
     </message>
     <message>
         <location filename="../idlenesswatchersettings.ui" line="131"/>
         <source>Backlight (%):</source>
-        <translation>Bagrunnsbelysning (%)</translation>
+        <translation>Bakgrunnsbelysning (%):</translation>
     </message>
     <message>
         <location filename="../idlenesswatchersettings.ui" line="158"/>
@@ -152,18 +152,18 @@
     <message>
         <location filename="../idlenesswatchersettings.ui" line="34"/>
         <source>When idle on AC:</source>
-        <translation>Ved lediggang på lysnettstilkobling:</translation>
+        <translation>Ved inaktivitet på nettstrøm:</translation>
     </message>
     <message>
         <location filename="../idlenesswatchersettings.ui" line="53"/>
         <source>AC Idle time:</source>
-        <translation>Lediggangstid på lysnett:</translation>
+        <translation>Inaktivitetstid på nettstrøm:</translation>
     </message>
     <message>
         <location filename="../idlenesswatchersettings.ui" line="63"/>
         <location filename="../idlenesswatchersettings.ui" line="97"/>
         <source>Minutes:Seconds (min: 01:30)</source>
-        <translation type="unfinished">minutter:sekunder (minimum:01:30)</translation>
+        <translation>Minutter:Sekunder (min: 01:30)</translation>
     </message>
     <message>
         <location filename="../idlenesswatchersettings.ui" line="185"/>
@@ -173,12 +173,12 @@
     <message>
         <location filename="../idlenesswatchersettings.ui" line="192"/>
         <source>On battery discharging </source>
-        <translation type="unfinished">Når batteriet utlades </translation>
+        <translation>Ved utladning av batteriet </translation>
     </message>
     <message>
         <location filename="../idlenesswatchersettings.ui" line="208"/>
         <source>Disable idleness checks when fullscreen</source>
-        <translation>Skru av lediggangssjekk i fullskjermsvisning</translation>
+        <translation>Slå av inaktivitetssjekk i fullskjermsvisning</translation>
     </message>
 </context>
 <context>
@@ -217,7 +217,7 @@
     <message>
         <location filename="../lidwatchersettings.ui" line="73"/>
         <source>Shut down</source>
-        <translation>Skru av</translation>
+        <translation>Slå av</translation>
     </message>
     <message>
         <location filename="../lidwatchersettings.ui" line="81"/>
@@ -256,7 +256,7 @@
     <message>
         <location filename="../mainwindow.cpp" line="52"/>
         <source>Power keys</source>
-        <translation>Effekt-taster</translation>
+        <translation>Strømtaster</translation>
     </message>
 </context>
 <context>
@@ -269,7 +269,7 @@
     <message>
         <location filename="../powerkeyssettings.ui" line="20"/>
         <source>Handle Power Keys</source>
-        <translation type="unfinished">Håndter effekt-taster</translation>
+        <translation>Håndter strømtaster</translation>
     </message>
     <message>
         <location filename="../powerkeyssettings.ui" line="26"/>
@@ -286,6 +286,11 @@
         <source>Hibernate Key Action:</source>
         <translation>Handling for dvaletast:</translation>
     </message>
+    <message>
+        <location filename="../powerkeyssettings.cpp" line="48"/>
+        <source>Note: Under Wayland, power keys are configured by the compositor instead.</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
@@ -317,7 +322,7 @@
     <message>
         <location filename="../helpers.cpp" line="43"/>
         <source>Shutdown</source>
-        <translation>Skru av</translation>
+        <translation>Slå av</translation>
     </message>
     <message>
         <location filename="../helpers.cpp" line="44"/>
