@@ -286,6 +286,11 @@
         <source>Hibernate Key Action:</source>
         <translation>Hibernate 的按键操作:</translation>
     </message>
+    <message>
+        <location filename="../powerkeyssettings.cpp" line="48"/>
+        <source>Note: Under Wayland, power keys are configured by the compositor instead.</source>
+        <translation>注意：在 Wayland 下，电源键由合成器配置。</translation>
+    </message>
 </context>
 <context>
     <name>QObject</name>
