@@ -282,9 +282,8 @@
         <location filename="../powermanagementd.cpp" line="116"/>
         <source>You are running LXQt Power Management for the first time.
 You can configure it from settings... </source>
-        <translation>Εκτελείτε την διαχείριση ενέργειας του LXQt για πρώτη φορά.
-Μπορείτε να την διαμορφώσετε από τις ρυθμίσεις... 
-</translation>
+        <translation>Εκτελείτε τη Διαχείριση Ενέργειας του LXQt για πρώτη φορά.
+Μπορείτε να τη διαμορφώσετε από τις ρυθμίσεις... </translation>
     </message>
     <message>
         <location filename="../powermanagementd.cpp" line="117"/>
@@ -295,73 +294,73 @@ You can configure it from settings... </source>
 <context>
     <name>TrayIcon</name>
     <message>
-        <location filename="../trayicon.cpp" line="67"/>
+        <location filename="../trayicon.cpp" line="68"/>
         <source>Configure</source>
         <translation>Διαμόρφωση</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="75"/>
+        <location filename="../trayicon.cpp" line="76"/>
         <source>30 minutes</source>
         <translation>30 λεπτά</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="79"/>
+        <location filename="../trayicon.cpp" line="80"/>
         <source>1 hour</source>
         <translation>1 ώρα</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="83"/>
+        <location filename="../trayicon.cpp" line="84"/>
         <source>2 hours</source>
         <translation>2 ώρες</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="87"/>
+        <location filename="../trayicon.cpp" line="88"/>
         <source>3 hours</source>
         <translation>3 ώρες</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="91"/>
+        <location filename="../trayicon.cpp" line="92"/>
         <source>4 hours</source>
         <translation>4 ώρες</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="96"/>
+        <location filename="../trayicon.cpp" line="97"/>
         <source>Pause idleness checks</source>
         <translation>Παύση των ελέγχων αδράνειας</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="101"/>
-        <location filename="../trayicon.cpp" line="193"/>
+        <location filename="../trayicon.cpp" line="102"/>
+        <location filename="../trayicon.cpp" line="194"/>
         <source>About</source>
         <translation>Σχετικά</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="103"/>
+        <location filename="../trayicon.cpp" line="104"/>
         <source>Disable icon</source>
         <translation>Απενεργοποίηση του εικονιδίου</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="162"/>
+        <location filename="../trayicon.cpp" line="163"/>
         <source>Empty</source>
         <translation>Αποφορτισμένος</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="194"/>
+        <location filename="../trayicon.cpp" line="195"/>
         <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
         <translation>&lt;p&gt;  &lt;b&gt;Διαχείριση ενέργειας LXQt&lt;/b&gt;&lt;br/&gt;  - Διαχείριση ενέργειας του περιβάλλοντος εργασίας LXQt&lt;/p&gt;&lt;p&gt;  Συγγραφείς:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - και λοιποί από τα έργα Razor και LXQt&lt;/p&gt;&lt;p&gt;  Πνευματικά δικαιώματα &amp;copy; 2012-2014&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="212"/>
+        <location filename="../trayicon.cpp" line="213"/>
         <source>LXQt Power Management info</source>
         <translation>Πληροφορίες της διαχείρισης ενέργειας του LXQt</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="213"/>
+        <location filename="../trayicon.cpp" line="214"/>
         <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
         <translation>Το εικονίδιο στο πλαίσο συστήματος μπορεί να (επαν)ενεργοποιηθεί από το &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="215"/>
+        <location filename="../trayicon.cpp" line="216"/>
         <source>Configure now</source>
         <translation>Διαμόρφωση τώρα</translation>
     </message>
