@@ -206,7 +206,7 @@
     <message>
         <location filename="../batteryinfoframe.cpp" line="65"/>
         <source>Empty</source>
-        <translation>거의 방전됨</translation>
+        <translation>방전됨</translation>
     </message>
 </context>
 <context>
@@ -214,7 +214,7 @@
     <message>
         <location filename="../batterywatcher.cpp" line="48"/>
         <source>No battery!</source>
-        <translation>배터리가 없습니다!</translation>
+        <translation>배터리 잔량이 없습니다!</translation>
     </message>
     <message>
         <location filename="../batterywatcher.cpp" line="49"/>
@@ -258,12 +258,12 @@
     <message>
         <location filename="../powerbutton.cpp" line="79"/>
         <source>Suspend key action</source>
-        <translation>대기 모드 키 작업</translation>
+        <translation>절전 키 작업</translation>
     </message>
     <message>
         <location filename="../powerbutton.cpp" line="86"/>
         <source>Hibernate key action</source>
-        <translation>최대 절전모드 키 동작</translation>
+        <translation>최대 절전 키 동작</translation>
     </message>
 </context>
 <context>
@@ -289,74 +289,74 @@ You can configure it from settings... </source>
 <context>
     <name>TrayIcon</name>
     <message>
-        <location filename="../trayicon.cpp" line="67"/>
+        <location filename="../trayicon.cpp" line="68"/>
         <source>Configure</source>
         <translation>구성하기</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="75"/>
+        <location filename="../trayicon.cpp" line="76"/>
         <source>30 minutes</source>
         <translation>30분</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="79"/>
+        <location filename="../trayicon.cpp" line="80"/>
         <source>1 hour</source>
         <translation>1시간</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="83"/>
+        <location filename="../trayicon.cpp" line="84"/>
         <source>2 hours</source>
         <translation>2시간</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="87"/>
+        <location filename="../trayicon.cpp" line="88"/>
         <source>3 hours</source>
         <translation>3시간</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="91"/>
+        <location filename="../trayicon.cpp" line="92"/>
         <source>4 hours</source>
         <translation>4시간</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="96"/>
+        <location filename="../trayicon.cpp" line="97"/>
         <source>Pause idleness checks</source>
         <translation>유휴 상태 검사 일시 중지</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="101"/>
-        <location filename="../trayicon.cpp" line="193"/>
+        <location filename="../trayicon.cpp" line="102"/>
+        <location filename="../trayicon.cpp" line="194"/>
         <source>About</source>
         <translation>정보</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="103"/>
+        <location filename="../trayicon.cpp" line="104"/>
         <source>Disable icon</source>
         <translation>아이콘 사용 안함</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="162"/>
+        <location filename="../trayicon.cpp" line="163"/>
         <source>Empty</source>
         <translation>거의 방전됨</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="194"/>
+        <location filename="../trayicon.cpp" line="195"/>
         <source>&lt;p&gt;  &lt;b&gt;LXQt Power Management&lt;/b&gt;&lt;br/&gt;  - Power Management for the LXQt Desktop Environment&lt;/p&gt;&lt;p&gt;  Authors:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt;  &amp;nbsp; - and others from the Razor and LXQt projects&lt;/p&gt;&lt;p&gt;  Copyright &amp;copy; 2012-2014&lt;/p&gt;</source>
         <translation>&lt;p&gt;  &lt;b&gt;LXQt 전원 관리&lt;/b&gt;&lt;br/&gt;  - LXQt 데스크탑 환경을 위한 전원 관리&lt;/p&gt;&lt;p&gt;  작성자:&lt;br/&gt;  &amp;nbsp; Christian Surlykke, Alec Moskvin&lt;br/&gt; 
  &amp;nbsp; - 그리고 Razor 및 LXQt 프로젝트의 다른 프로젝트들&lt;/p&gt;&lt;p&gt; Copyright &amp;copy; 2012-2014&lt;/p&gt;&lt;p&gt;  번역자:&lt;br/&gt;  &amp;nbsp; 이정희 &lt;daemul72@gmail.com&gt;&lt;/p&gt;</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="212"/>
+        <location filename="../trayicon.cpp" line="213"/>
         <source>LXQt Power Management info</source>
         <translation>LXQt 전원 관리 정보</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="213"/>
+        <location filename="../trayicon.cpp" line="214"/>
         <source>The LXQt Power Management tray icon can be (re)enabled in &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;</source>
         <translation>LXQt 전원 관리 트레이 아이콘은 &lt;i&gt;lxqt-config-powermanagement&lt;/i&gt;에서 (재)활성화할 수 있습니다</translation>
     </message>
     <message>
-        <location filename="../trayicon.cpp" line="215"/>
+        <location filename="../trayicon.cpp" line="216"/>
         <source>Configure now</source>
         <translation>지금 구성하기</translation>
     </message>
