@@ -19,8 +19,8 @@ class Watcher : public QObject
     Q_OBJECT
 
 public:
-    Watcher(QObject *parent = 0);
-    virtual ~Watcher();
+    Watcher(QObject *parent = nullptr);
+    ~Watcher() override;
 
 protected:
     void doAction(int action);
